@@ -183,7 +183,6 @@ function multilogin_sqoverride_config_do()
 //TODO: use $currentHookName instead of this backtrace hassle when $currentHookName
 //      is part of more than just SM 1.5.1 (or part of compatibility plugin?)
                //
-               $hookName = '';
                $backtrace = debug_backtrace();
                foreach ($backtrace as $trace)
                   if ($trace['function'] == 'do_hook'
@@ -191,9 +190,7 @@ function multilogin_sqoverride_config_do()
                    || $trace['function'] == 'concat_hook_function'
                    || $trace['function'] == 'boolean_hook_function')
                      $hookName = $trace['args'][0];
-
-               if (!empty($hookName))
-                  $originalHookFunctions = $squirrelmail_plugin_hooks[$hookName];
+               $originalHookFunctions = $squirrelmail_plugin_hooks[$hookName];
 
                $plugins[] = $pluginName;
                if (function_exists('use_plugin'))
@@ -202,19 +199,16 @@ function multilogin_sqoverride_config_do()
                // now get any new plugins for the current hook
                // and run their hooks
                //
-               if (!empty($hookName))
-               {
-                  $newHookFunctions = array_diff($squirrelmail_plugin_hooks[$hookName], 
-                                                 $originalHookFunctions);
-                  foreach ($newHookFunctions as $function)
-                     if (function_exists($function))
+               $newHookFunctions = array_diff($squirrelmail_plugin_hooks[$hookName], 
+                                              $originalHookFunctions);
+               foreach ($newHookFunctions as $function)
+                  if (function_exists($function))
 // TODO: currently this code never gets run in a hook that needs data
 //       passed to it or needs to return something, so the following 
 //       call is fine, but if that ever changes, we'll need to get
 //       the other function args from the backtrace and make the right
 //       kind of call, etc.
-                        $function();
-               }
+                     $function();
 
             }
             continue;
