@@ -33,7 +33,7 @@ if (!defined('SM_PATH'))
 
 function multilogin_version()
 {
-   return '2.3.1';
+   return '2.3';
 }
 
 
